@@ -4,10 +4,12 @@ import json
 from typing import Dict, Tuple, Type
 
 import attr
+from morecantile import TileMatrixSet
 from rasterio.features import bounds as featureBounds
 
+from rio_tiler.constants import WEB_MERCATOR_TMS
 from rio_tiler.errors import InvalidBandName
-from rio_tiler.io import BaseReader, GCPCOGReader, MultiBandReader
+from rio_tiler.io import GCPCOGReader, MultiBandReader
 
 from ... import get_object
 from ..utils import s1_sceneid_parser
@@ -34,10 +36,11 @@ class S1L1CReader(MultiBandReader):
     """
 
     sceneid: str = attr.ib()
-    reader: Type[BaseReader] = attr.ib(default=GCPCOGReader)
+    reader: Type[GCPCOGReader] = attr.ib(default=GCPCOGReader)
     reader_options: Dict = attr.ib(default={"nodata": 0})
-    minzoom: int = attr.ib(init=False, default=8)
-    maxzoom: int = attr.ib(init=False, default=14)
+    tms: TileMatrixSet = attr.ib(default=WEB_MERCATOR_TMS)
+    minzoom: int = attr.ib(default=8)
+    maxzoom: int = attr.ib(default=14)
 
     bands: Tuple = attr.ib(init=False, default=("vv", "vh"))
     productInfo: Dict = attr.ib(init=False)
@@ -58,14 +61,6 @@ class S1L1CReader(MultiBandReader):
         self.datageom = self.productInfo["footprint"]
         self.bounds = featureBounds(self.datageom)
 
-    def __enter__(self):
-        """Support using with Context Managers."""
-        return self
-
-    def __exit__(self, exc_type, exc_value, traceback):
-        """Support using with Context Managers."""
-        pass
-
     def _get_band_url(self, band: str) -> str:
         """Validate band name and return band's url."""
         if band not in self.bands:
